@@ -13,6 +13,7 @@ from shutil import which
 import sys
 import platform
 from typing import Optional
+from packaging import version
 
 # Linux
 # ('Linux', '5.4.0-52-generic', '#57-Ubuntu SMP Thu Oct 15 10:57:00 UTC 2020')
@@ -350,7 +351,7 @@ def start(
         result = runCommand(docker_compose_command, project_dir)
         if result.returncode != 0:
             typer.secho(
-                f"Failed to start {service} in {backplane['active_context_dir']}: {result.stdout}",
+                f"Failed to start {service} in {backplane['active_context_dir']}: {result.stderr}",
                 err=True,
                 fg=typer.colors.RED,
             )
@@ -573,6 +574,19 @@ def checkPrerequisites():
     if not which("docker-compose"):
         typer.secho("docker-compose not installed", err=True, fg=typer.colors.RED)
         sys.exit(1)
+    else:
+        docker_compose_version = subprocess.run(
+            ["docker-compose", "-v"], capture_output=True
+        )
+        doco_version = docker_compose_version.stdout.decode().split(" ")[2].strip(",")
+
+        if version.parse(doco_version) < version.parse("1.27.4"):
+            typer.secho(
+                f"docker-compose version {doco_version} does not match minimum required version 1.27.4",
+                err=True,
+                fg=typer.colors.RED,
+            )
+            sys.exit(1)
 
     if not which("git"):
         typer.secho("git not installed", err=True, fg=typer.colors.RED)
